@@ -33,12 +33,23 @@ int ipmi_oem_inventec_set_bmc_services (ipmi_oem_state_data_t *state_data);
 int ipmi_oem_inventec_get_authentication_config (ipmi_oem_state_data_t *state_data);
 int ipmi_oem_inventec_set_authentication_config (ipmi_oem_state_data_t *state_data);
 
+int ipmi_oem_inventec_get_account_status (ipmi_oem_state_data_t *state_data);
+
+int ipmi_oem_inventec_get_dns_config (ipmi_oem_state_data_t *state_data);
+int ipmi_oem_inventec_set_dns_config (ipmi_oem_state_data_t *state_data);
+
 int ipmi_oem_inventec_get_web_server_config (ipmi_oem_state_data_t *state_data);
 int ipmi_oem_inventec_set_web_server_config (ipmi_oem_state_data_t *state_data);
 
 int ipmi_oem_inventec_get_power_management_config (ipmi_oem_state_data_t *state_data);
 int ipmi_oem_inventec_set_power_management_config (ipmi_oem_state_data_t *state_data);
 
+int ipmi_oem_inventec_get_sol_idle_timeout (ipmi_oem_state_data_t *state_data);
+int ipmi_oem_inventec_set_sol_idle_timeout (ipmi_oem_state_data_t *state_data);
+
+int ipmi_oem_inventec_get_telnet_ssh_redirect_status (ipmi_oem_state_data_t *state_data);
+int ipmi_oem_inventec_set_telnet_ssh_redirect_status (ipmi_oem_state_data_t *state_data);
+
 #if 0
 /* waiting for verification from Dell */
 int ipmi_oem_inventec_get_firmware_update_config (ipmi_oem_state_data_t *state_data);
@@ -55,11 +66,28 @@ int ipmi_oem_inventec_get_firmware_information (ipmi_oem_state_data_t *state_dat
 int ipmi_oem_inventec_update_firmware (ipmi_oem_state_data_t *state_data);
 #endif
 
+int ipmi_oem_inventec_get_board_id (ipmi_oem_state_data_t *state_data);
+int ipmi_oem_inventec_set_board_id (ipmi_oem_state_data_t *state_data);
+
+int ipmi_oem_inventec_get_fcb_version (ipmi_oem_state_data_t *state_data);
+int ipmi_oem_inventec_set_fcb_version (ipmi_oem_state_data_t *state_data);
+
 #if 0
 /* cannot verify */
-int ipmi_oem_inventec_restore_to_defaults (ipmi_oem_state_data_t *state_data);
+int ipmi_oem_inventec_set_asset_tag (ipmi_oem_state_data_t *state_data);
 #endif
 
+#if 0
+/* cannot verify */
+int ipmi_oem_inventec_get_dhcp_retry (ipmi_oem_state_data_t *state_data);
+int ipmi_oem_inventec_set_dhcp_retry (ipmi_oem_state_data_t *state_data);
+#endif
+
+int ipmi_oem_inventec_get_sol_inactivity_timeout (ipmi_oem_state_data_t *state_data);
+int ipmi_oem_inventec_set_sol_inactivity_timeout (ipmi_oem_state_data_t *state_data);
+
+int ipmi_oem_inventec_restore_to_defaults (ipmi_oem_state_data_t *state_data);
+
 #if 0
 /* cannot verify */
 int ipmi_oem_inventec_set_system_guid (ipmi_oem_state_data_t *state_data);
