@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2007-2009 FreeIPMI Core Team
+  Copyright (C) 2007-2010 FreeIPMI Core Team
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -1974,6 +1974,6 @@ ipmi_pef_config_event_filter_table_section_get (ipmi_pef_config_state_data_t *st
 
  cleanup:
   if (section)
-    config_section_destroy (state_data->pstate, section);
+    config_section_destroy (section);
   return (NULL);
 }
