@@ -729,8 +729,8 @@ _detailed_output_resolution (ipmi_sensors_state_data_t *state_data,
 
 static int
 _detailed_output_accuracy (ipmi_sensors_state_data_t *state_data,
-                            const void *sdr_record,
-                            unsigned int sdr_record_len)
+                           const void *sdr_record,
+                           unsigned int sdr_record_len)
 {
   double *accuracy = NULL;
   int rv = -1;
@@ -741,9 +741,9 @@ _detailed_output_accuracy (ipmi_sensors_state_data_t *state_data,
   assert (state_data->prog_data->args->verbose_count >= 2);
 
   if (ipmi_sdr_parse_accuracy (state_data->sdr_parse_ctx,
-                                sdr_record,
-                                sdr_record_len,
-                                &accuracy) < 0)
+                               sdr_record,
+                               sdr_record_len,
+                               &accuracy) < 0)
     {
       pstdout_fprintf (state_data->pstate,
                        stderr,
@@ -1127,7 +1127,9 @@ _detailed_output_event_enable (ipmi_sensors_state_data_t *state_data,
           && (ipmi_check_completion_code (obj_cmd_rs,
                                           IPMI_COMP_CODE_COMMAND_ILLEGAL_FOR_SENSOR_OR_RECORD_TYPE) == 1
               || ipmi_check_completion_code (obj_cmd_rs,
-                                             IPMI_COMP_CODE_REQUEST_SENSOR_DATA_OR_RECORD_NOT_PRESENT) == 1))
+                                             IPMI_COMP_CODE_REQUEST_SENSOR_DATA_OR_RECORD_NOT_PRESENT) == 1
+	      || ipmi_check_completion_code (obj_cmd_rs,
+					     IPMI_COMP_CODE_COMMAND_RESPONSE_COULD_NOT_BE_PROVIDED) == 1))
         {
           /* The event enables cannot be gathered for one reason or
            * another, maybe b/c its a OEM sensor or something.  Just
