@@ -58,27 +58,6 @@ extern "C" {
 #define IPMI_CMD_OEM_DELL_GET_ACTIVE_LOM_STATUS                                0xC1
 #define IPMI_CMD_OEM_DELL_IDRAC_VIRTUAL_MAC                                    0xC9
 
-/*
- * Dell Xanadu II
- * Dell Xanadu III
- */
-
-/* IPMI_NET_FN_FIRMWARE_RQ / IPMI_NET_FN_FIRMWARE_RS */
-#define IPMI_CMD_OEM_DELL_UPDATE_FIRMWARE   0x01
-#define IPMI_CMD_OEM_DELL_GET_UPDATE_STATUS 0x02
-#define IPMI_CMD_OEM_DELL_COPY_IMAGE_DATA   0x03
-
-/* IPMI_NET_FN_OEM_DELL_XANADU_RQ / IPMI_NET_FN_OEM_DELL_XANADU_RS */ 
-#define IPMI_CMD_OEM_DELL_SET_WEB_PORT_NUM    0x02
-#define IPMI_CMD_OEM_DELL_GET_WEB_PORT_NUM    0x03
-#define IPMI_CMD_OEM_DELL_SET_BOARD_ID        0x10
-#define IPMI_CMD_OEM_DELL_GET_BOARD_ID        0x11
-#define IPMI_CMD_OEM_DELL_SET_ASSET_TAG       0x12
-#define IPMI_CMD_OEM_DELL_SET_LAN_SOURCE      0x13
-#define IPMI_CMD_OEM_DELL_GET_LAN_SOURCE      0x14
-#define IPMI_CMD_OEM_DELL_SET_FCB_FW_VERSION  0x15
-#define IPMI_CMD_OEM_DELL_GET_FCB_FW_VERSION  0x16
-
 /******************************************* 
  * Fujitsu                                 *
  *******************************************/
@@ -114,6 +93,22 @@ extern "C" {
 /* achu: not official names, named based on use context */
 #define IPMI_CMD_OEM_IBM_GET_LED 0xC0
 
+/*******************************************
+ * Intel                                   *
+ *******************************************/
+
+/*
+ * Intel S5500WB/Penguin Computing Relion 700
+ */
+
+/* IPMI_NET_FN_OEM_INTEL_GENERIC_RQ / IPMI_NET_FN_OEM_INTEL_GENERIC_RS */
+#define IPMI_CMD_OEM_INTEL_RESTORE_CONFIGURATION 0x02
+#define IPMI_CMD_OEM_INTEL_SET_FAULT_INDICATION  0x57
+
+/* IPMI_NET_FN_OEM_INTEL_CONFIG_RQ / IPMI_NET_FN_OEM_INTEL_CONFIG_RS */
+#define IPMI_CMD_OEM_INTEL_SET_SMTP_CONFIGURATION 0x37
+#define IPMI_CMD_OEM_INTEL_GET_SMTP_CONFIGURATION 0x38
+
 /******************************************* 
  * Inventec                                *
  *******************************************/
@@ -128,6 +123,11 @@ extern "C" {
 #define IPMI_CMD_OEM_INVENTEC_GET_UPDATE_STATUS 0x02
 #define IPMI_CMD_OEM_INVENTEC_COPY_IMAGE_DATA   0x03
 
+/* IPMI_NET_FN_OEM_GROUP_RQ / IPMI_NET_FN_OEM_GROUP_RS */
+/* achu: not official names, named based on use context */
+#define IPMI_CMD_OEM_INVENTEC_SET_DEDICATED_MAC_ADDRESS    0x21
+#define IPMI_CMD_OEM_INVENTEC_SET_SHARED_MAC_ADDRESS       0x23
+
 /* IPMI_NET_FN_OEM_INVENTEC_GENERIC_RQ / IPMI_NET_FN_OEM_INVENTEC_GENERIC_RS */
 #define IPMI_CMD_OEM_INVENTEC_RESERVED_EXTENDED_CONFIGUATION 0x01
 #define IPMI_CMD_OEM_INVENTEC_GET_EXTENDED_CONFIGURATION     0x02
@@ -136,17 +136,36 @@ extern "C" {
 #define IPMI_CMD_OEM_INVENTEC_GET_RESTORE_STATUS             0x05
 #define IPMI_CMD_OEM_INVENTEC_SET_SYSTEM_GUID                0xB3
 
-/* IPMI_NET_FN_OEM_GROUP_RQ / IPMI_NET_FN_OEM_GROUP_RS */
-/* achu: not official names, named based on use context */
-#define IPMI_CMD_OEM_INVENTEC_SET_DEDICATED_MAC_ADDRESS    0x21
-#define IPMI_CMD_OEM_INVENTEC_SET_SHARED_MAC_ADDRESS       0x23
+/* IPMI_NET_FN_OEM_INVENTEC_SPECIFIC_RQ / IPMI_NET_FN_OEM_INVENTEC_SPECIFIC_RS */ 
+#define IPMI_CMD_OEM_INVENTEC_SET_WEB_PORT_NUM                0x02
+#define IPMI_CMD_OEM_INVENTEC_GET_WEB_PORT_NUM                0x03
+#define IPMI_CMD_OEM_INVENTEC_SET_BOARD_ID                    0x10
+#define IPMI_CMD_OEM_INVENTEC_GET_BOARD_ID                    0x11
+#define IPMI_CMD_OEM_INVENTEC_SET_ASSET_TAG                   0x12
+#define IPMI_CMD_OEM_INVENTEC_SET_LAN_SOURCE                  0x13
+#define IPMI_CMD_OEM_INVENTEC_GET_LAN_SOURCE                  0x14
+#define IPMI_CMD_OEM_INVENTEC_SET_FCB_FW_VERSION              0x15
+#define IPMI_CMD_OEM_INVENTEC_GET_FCB_FW_VERSION              0x16
+#define IPMI_CMD_OEM_INVENTEC_SET_FAN_CONTROL                 0x61
+#define IPMI_CMD_OEM_INVENTEC_GET_FAN_CONTROL                 0x62
+#define IPMI_CMD_OEM_INVENTEC_SET_FSC_TABLE                   0x63
+#define IPMI_CMD_OEM_INVENTEC_GET_FSC_TABLE                   0x64
+#define IPMI_CMD_OEM_INVENTEC_GET_FCB_SKU_INFO                0x6A
+#define IPMI_CMD_OEM_INVENTEC_GET_FCB_POWER_THROTTLING_STATUS 0x6B
+#define IPMI_CMD_OEM_INVENTEC_OEM_GET_PIC_MODEL               0x70
+#define IPMI_CMD_OEM_INVENTEC_OEM_SET_FLASH_PIN               0x71
+#define IPMI_CMD_OEM_INVENTEC_OEM_GET_FLASH_PIN               0x72
+#define IPMI_CMD_OEM_INVENTEC_OEM_NEW_MASTER_WRITE_READ       0x73
+#define IPMI_CMD_OEM_INVENTEC_SET_POWER_THROTTLING_BEHAVIOR   0xB1
+#define IPMI_CMD_OEM_INVENTEC_GET_POWER_THROTTLING_BEHAVIOR   0xB2
+#define IPMI_CMD_OEM_INVENTEC_GET_PSU_MISMATCH_AND_TYPE       0xB3
 
 /******************************************* 
  * Quanta                                  *
  *******************************************/
 
 /*
- * Quanta S99Q/Dell TS12-TY
+ * Quanta S99Q/Dell FS12-TY
  */
 
 /* IPMI_NET_FN_FIRMWARE_RQ / IPMI_NET_FN_FIRMWARE_RS */
@@ -156,7 +175,9 @@ extern "C" {
 #define IPMI_CMD_OEM_QUANTA_USB_FIRMWARE_UPDATE 0x04
 
 /* IPMI_NET_FN_OEM_QUANTA_GENERIC_RQ / IPMI_NET_FN_OEM_QUANTA_GENERIC_RS */
+#define IPMI_CMD_OEM_QUANTA_RESERVED_EXTENDED_CONFIGUATION    0x01
 #define IPMI_CMD_OEM_QUANTA_GET_EXTENDED_CONFIGURATION        0x02
+#define IPMI_CMD_OEM_QUANTA_SET_EXTENDED_CONFIGURATION        0x03
 #define IPMI_CMD_OEM_QUANTA_RESET_TO_DEFAULTS                 0x04
 #define IPMI_CMD_OEM_QUANTA_GET_RESTORE_STATUS                0x05
 #define IPMI_CMD_OEM_QUANTA_GET_SENSOR_TEMPERATURE_READING    0x10
