@@ -44,12 +44,16 @@ extern "C" {
 #define IPMI_INTEL_PRODUCT_ID_SR870BN4 256
 #define IPMI_INTEL_PRODUCT_ID_TIGER4   IPMI_INTEL_PRODUCT_ID_SR870BN4
 
+#define IPMI_INTEL_PRODUCT_ID_S5500WB  62
+
 /* 
  * Intel derived
  */
 
 #define IPMI_CALIFORNIA_DIGITAL_PRODUCT_ID_6440 IPMI_INTEL_PRODUCT_ID_SR870BN4
 
+#define IPMI_PENGUIN_COMPUTING_PRODUCT_ID_RELION_700 IPMI_INTEL_PRODUCT_ID_S5500WB
+
 /*******************************************
  * IBM                                     *
  *******************************************/
@@ -81,7 +85,7 @@ extern "C" {
  * Quanta derived
  */
 
-#define IPMI_DELL_PRODUCT_ID_TS12_TY IPMI_QUANTA_PRODUCT_ID_S99Q
+#define IPMI_DELL_PRODUCT_ID_FS12_TY IPMI_QUANTA_PRODUCT_ID_S99Q
 
 /******************************************* 
  * Sun Microsystems                        *
