@@ -62,6 +62,7 @@
 #include "ipmi-sel-parse-common.h"
 #include "ipmi-sel-parse-defs.h"
 #include "ipmi-sel-parse-string.h"
+#include "ipmi-sel-parse-string-intel-node-manager.h"
 #include "ipmi-sel-parse-string-inventec.h"
 #include "ipmi-sel-parse-trace.h"
 #include "ipmi-sel-parse-util.h"
@@ -89,6 +90,7 @@ ipmi_sel_parse_output_inventec_sensor_name (ipmi_sel_parse_ctx_t ctx,
 {
   assert (ctx);
   assert (ctx->magic == IPMI_SEL_PARSE_CTX_MAGIC);
+  assert (ctx->manufacturer_id == IPMI_IANA_ENTERPRISE_ID_INVENTEC);
   assert (sel_parse_entry);
   assert (buf);
   assert (buflen);
@@ -103,35 +105,52 @@ ipmi_sel_parse_output_inventec_sensor_name (ipmi_sel_parse_ctx_t ctx,
    * Inventec 5441/Dell Xanadu II
    * Inventec 5442/Dell Xanadu III
    */
-  if (ctx->manufacturer_id == IPMI_IANA_ENTERPRISE_ID_INVENTEC
-      && (ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5441
-          || ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5442)
-      && ((system_event_record_data->generator_id == IPMI_GENERATOR_ID_OEM_INVENTEC_BIOS 
-           && system_event_record_data->event_type_code == IPMI_EVENT_READING_TYPE_CODE_OEM_INVENTEC_BIOS
-           && system_event_record_data->sensor_type == IPMI_SENSOR_TYPE_OEM_INVENTEC_BIOS
-           && system_event_record_data->sensor_number == IPMI_SENSOR_NUMBER_OEM_INVENTEC_POST_START)
-          || (system_event_record_data->generator_id == IPMI_GENERATOR_ID_OEM_INVENTEC_BIOS 
-              && system_event_record_data->event_type_code == IPMI_EVENT_READING_TYPE_CODE_SENSOR_SPECIFIC
-              && system_event_record_data->sensor_type == IPMI_SENSOR_TYPE_SYSTEM_EVENT
-              && system_event_record_data->sensor_number == IPMI_SENSOR_NUMBER_OEM_INVENTEC_POST_OK)
-          || (system_event_record_data->generator_id == IPMI_GENERATOR_ID_OEM_INVENTEC_POST_ERROR_CODE
-              && system_event_record_data->event_type_code == IPMI_EVENT_READING_TYPE_CODE_SENSOR_SPECIFIC
-              && system_event_record_data->sensor_type == IPMI_SENSOR_TYPE_SYSTEM_FIRMWARE_PROGRESS
-              && system_event_record_data->sensor_number == IPMI_SENSOR_NUMBER_OEM_INVENTEC_POST_ERROR_CODE)
-          || (system_event_record_data->generator_id == IPMI_SLAVE_ADDRESS_BMC
-              && system_event_record_data->event_type_code == IPMI_EVENT_READING_TYPE_CODE_SENSOR_SPECIFIC
-              && system_event_record_data->sensor_type == IPMI_SENSOR_TYPE_SYSTEM_FIRMWARE_PROGRESS
-              && system_event_record_data->sensor_number == IPMI_SENSOR_NUMBER_OEM_INVENTEC_PORT80_CODE_EVENT)))
+  if (ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5441
+      || ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5442)
     {
-      if (ipmi_sel_parse_string_snprintf (buf,
-					  buflen,
-					  wlen,
-					  "BIOS"))
-        (*oem_rv) = 1;
-      else
-        (*oem_rv) = 0;
+      int nmret;
+
+      if (((system_event_record_data->generator_id == IPMI_GENERATOR_ID_OEM_INVENTEC_BIOS 
+	    && system_event_record_data->event_type_code == IPMI_EVENT_READING_TYPE_CODE_OEM_INVENTEC_BIOS
+	    && system_event_record_data->sensor_type == IPMI_SENSOR_TYPE_OEM_INVENTEC_BIOS
+	    && system_event_record_data->sensor_number == IPMI_SENSOR_NUMBER_OEM_INVENTEC_POST_START)
+	   || (system_event_record_data->generator_id == IPMI_GENERATOR_ID_OEM_INVENTEC_BIOS 
+	       && system_event_record_data->event_type_code == IPMI_EVENT_READING_TYPE_CODE_SENSOR_SPECIFIC
+	       && system_event_record_data->sensor_type == IPMI_SENSOR_TYPE_SYSTEM_EVENT
+	       && system_event_record_data->sensor_number == IPMI_SENSOR_NUMBER_OEM_INVENTEC_POST_OK)
+	   || (system_event_record_data->generator_id == IPMI_GENERATOR_ID_OEM_INVENTEC_POST_ERROR_CODE
+	       && system_event_record_data->event_type_code == IPMI_EVENT_READING_TYPE_CODE_SENSOR_SPECIFIC
+	       && system_event_record_data->sensor_type == IPMI_SENSOR_TYPE_SYSTEM_FIRMWARE_PROGRESS
+	       && system_event_record_data->sensor_number == IPMI_SENSOR_NUMBER_OEM_INVENTEC_POST_ERROR_CODE)
+	   || (system_event_record_data->generator_id == IPMI_SLAVE_ADDRESS_BMC
+	       && system_event_record_data->event_type_code == IPMI_EVENT_READING_TYPE_CODE_SENSOR_SPECIFIC
+	       && system_event_record_data->sensor_type == IPMI_SENSOR_TYPE_SYSTEM_FIRMWARE_PROGRESS
+	       && system_event_record_data->sensor_number == IPMI_SENSOR_NUMBER_OEM_INVENTEC_PORT80_CODE_EVENT)))
+	{
+	  if (ipmi_sel_parse_string_snprintf (buf,
+					      buflen,
+					      wlen,
+					      "BIOS"))
+	    (*oem_rv) = 1;
+	  else
+	    (*oem_rv) = 0;
+	
+	  return (1);
+	}
+
+      if ((nmret = ipmi_sel_parse_output_intel_node_manager_sensor_name (ctx,
+									 sel_parse_entry,
+									 sel_record_type,
+									 buf,
+									 buflen,
+									 flags,
+									 wlen,
+									 system_event_record_data,
+									 oem_rv)) < 0)
+        return (-1);
       
-      return (1);
+      if (nmret)
+        return (1);      
     }
   
   return (0);
@@ -156,6 +175,7 @@ ipmi_sel_parse_output_inventec_event_data1_class_oem (ipmi_sel_parse_ctx_t ctx,
 {
   assert (ctx);
   assert (ctx->magic == IPMI_SEL_PARSE_CTX_MAGIC);
+  assert (ctx->manufacturer_id == IPMI_IANA_ENTERPRISE_ID_INVENTEC);
   assert (sel_parse_entry);
   assert (tmpbuf);
   assert (tmpbuflen);
@@ -173,22 +193,38 @@ ipmi_sel_parse_output_inventec_event_data1_class_oem (ipmi_sel_parse_ctx_t ctx,
    * from the vendor.  "BMC enabled by BIOS" is simply what
    * occurs, so that's what I'm going to say.
    */
-  if (ctx->manufacturer_id == IPMI_IANA_ENTERPRISE_ID_INVENTEC
-      && (ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5441
-          || ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5442)
-      && system_event_record_data->generator_id == IPMI_GENERATOR_ID_OEM_INVENTEC_BIOS
-      && system_event_record_data->sensor_type == IPMI_SENSOR_TYPE_OEM_INVENTEC_BIOS
-      && system_event_record_data->sensor_number == IPMI_SENSOR_NUMBER_OEM_INVENTEC_POST_START
-      && system_event_record_data->event_type_code == IPMI_EVENT_READING_TYPE_CODE_OEM_INVENTEC_BIOS
-      && !system_event_record_data->offset_from_event_reading_type_code /* no event */
-      && system_event_record_data->event_data2_flag == IPMI_SEL_EVENT_DATA_OEM_CODE
-      && system_event_record_data->event_data3_flag == IPMI_SEL_EVENT_DATA_OEM_CODE)
+  if (ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5441
+      || ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5442)
     {
-      snprintf (tmpbuf,
-                tmpbuflen,
-                "BMC enabled by BIOS");
+      int nmret;
 
-      return (1);
+      if (system_event_record_data->generator_id == IPMI_GENERATOR_ID_OEM_INVENTEC_BIOS
+          && system_event_record_data->sensor_type == IPMI_SENSOR_TYPE_OEM_INVENTEC_BIOS
+          && system_event_record_data->sensor_number == IPMI_SENSOR_NUMBER_OEM_INVENTEC_POST_START
+          && system_event_record_data->event_type_code == IPMI_EVENT_READING_TYPE_CODE_OEM_INVENTEC_BIOS
+          && !system_event_record_data->offset_from_event_reading_type_code /* no event */
+          && system_event_record_data->event_data2_flag == IPMI_SEL_EVENT_DATA_OEM_CODE
+          && system_event_record_data->event_data3_flag == IPMI_SEL_EVENT_DATA_OEM_CODE)
+        {
+          snprintf (tmpbuf,
+                    tmpbuflen,
+                    "BMC enabled by BIOS");
+          
+          return (1);
+        }
+
+      if ((nmret = ipmi_sel_parse_output_intel_node_manager_event_data1_class_oem (ctx,
+                                                                                   sel_parse_entry,
+                                                                                   sel_record_type,
+                                                                                   tmpbuf,
+                                                                                   tmpbuflen,
+                                                                                   flags,
+                                                                                   wlen,
+                                                                                   system_event_record_data)) < 0)
+        return (-1);
+
+      if (nmret)
+        return (1);
     }
 
   return (0);
@@ -213,6 +249,7 @@ ipmi_sel_parse_output_inventec_event_data2_discrete_oem (ipmi_sel_parse_ctx_t ct
 {
   assert (ctx);
   assert (ctx->magic == IPMI_SEL_PARSE_CTX_MAGIC);
+  assert (ctx->manufacturer_id == IPMI_IANA_ENTERPRISE_ID_INVENTEC);
   assert (sel_parse_entry);
   assert (tmpbuf);
   assert (tmpbuflen);
@@ -234,9 +271,8 @@ ipmi_sel_parse_output_inventec_event_data2_discrete_oem (ipmi_sel_parse_ctx_t ct
    * a rolling window.  Once the logging limit is reached, a system
    * reboot is necessary to reset the counter.
    */
-  if (ctx->manufacturer_id == IPMI_IANA_ENTERPRISE_ID_INVENTEC
-      && (ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5441
-          || ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5442)
+  if ((ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5441
+       || ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5442)
       && system_event_record_data->generator_id == IPMI_GENERATOR_ID_OEM_INVENTEC_SMI
       && system_event_record_data->sensor_type == IPMI_SENSOR_TYPE_MEMORY
       && system_event_record_data->sensor_number == IPMI_SENSOR_NUMBER_OEM_INVENTEC_MEMORY
@@ -287,6 +323,7 @@ ipmi_sel_parse_output_inventec_event_data2_class_oem (ipmi_sel_parse_ctx_t ctx,
 {
   assert (ctx);
   assert (ctx->magic == IPMI_SEL_PARSE_CTX_MAGIC);
+  assert (ctx->manufacturer_id == IPMI_IANA_ENTERPRISE_ID_INVENTEC);
   assert (sel_parse_entry);
   assert (tmpbuf);
   assert (tmpbuflen);
@@ -300,23 +337,39 @@ ipmi_sel_parse_output_inventec_event_data2_class_oem (ipmi_sel_parse_ctx_t ctx,
    * Inventec 5441/Dell Xanadu II
    * Inventec 5442/Dell Xanadu III
    */
-  if (ctx->manufacturer_id == IPMI_IANA_ENTERPRISE_ID_INVENTEC
-      && (ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5441
-          || ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5442)
-      && system_event_record_data->generator_id == IPMI_GENERATOR_ID_OEM_INVENTEC_BIOS
-      && system_event_record_data->sensor_type == IPMI_SENSOR_TYPE_OEM_INVENTEC_BIOS
-      && system_event_record_data->sensor_number == IPMI_SENSOR_NUMBER_OEM_INVENTEC_POST_START
-      && system_event_record_data->event_type_code == IPMI_EVENT_READING_TYPE_CODE_OEM_INVENTEC_BIOS
-      && !system_event_record_data->offset_from_event_reading_type_code /* no event */
-      && system_event_record_data->event_data2_flag == IPMI_SEL_EVENT_DATA_OEM_CODE
-      && system_event_record_data->event_data3_flag == IPMI_SEL_EVENT_DATA_OEM_CODE)
+  if (ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5441
+      || ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5442)
     {
-      snprintf (tmpbuf,
-                tmpbuflen,
-                "BIOS Major Version %X",
-                system_event_record_data->event_data2);
+      int nmret;
 
-      return (1);
+      if (system_event_record_data->generator_id == IPMI_GENERATOR_ID_OEM_INVENTEC_BIOS
+          && system_event_record_data->sensor_type == IPMI_SENSOR_TYPE_OEM_INVENTEC_BIOS
+          && system_event_record_data->sensor_number == IPMI_SENSOR_NUMBER_OEM_INVENTEC_POST_START
+          && system_event_record_data->event_type_code == IPMI_EVENT_READING_TYPE_CODE_OEM_INVENTEC_BIOS
+          && !system_event_record_data->offset_from_event_reading_type_code /* no event */
+          && system_event_record_data->event_data2_flag == IPMI_SEL_EVENT_DATA_OEM_CODE
+          && system_event_record_data->event_data3_flag == IPMI_SEL_EVENT_DATA_OEM_CODE)
+        {
+          snprintf (tmpbuf,
+                    tmpbuflen,
+                    "BIOS Major Version %X",
+                    system_event_record_data->event_data2);
+          
+          return (1);
+        }
+
+      if ((nmret = ipmi_sel_parse_output_intel_node_manager_event_data2_class_oem (ctx,
+                                                                                   sel_parse_entry,
+                                                                                   sel_record_type,
+                                                                                   tmpbuf,
+                                                                                   tmpbuflen,
+                                                                                   flags,
+                                                                                   wlen,
+                                                                                   system_event_record_data)) < 0)
+        return (-1);
+      
+      if (nmret)
+        return (1);
     }
   
   return (0);
@@ -341,6 +394,7 @@ ipmi_sel_parse_output_inventec_event_data3_discrete_oem (ipmi_sel_parse_ctx_t ct
 {
   assert (ctx);
   assert (ctx->magic == IPMI_SEL_PARSE_CTX_MAGIC);
+  assert (ctx->manufacturer_id == IPMI_IANA_ENTERPRISE_ID_INVENTEC);
   assert (sel_parse_entry);
   assert (tmpbuf);
   assert (tmpbuflen);
@@ -355,8 +409,7 @@ ipmi_sel_parse_output_inventec_event_data3_discrete_oem (ipmi_sel_parse_ctx_t ct
    * Inventec 5441/Dell Xanadu II
    */
 
-  if (ctx->manufacturer_id == IPMI_IANA_ENTERPRISE_ID_INVENTEC
-      && ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5441)
+  if (ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5441)
     {
       /* achu: Note that the Dimm locations are not in a pattern,
        * this is what the doc says.
@@ -428,8 +481,7 @@ ipmi_sel_parse_output_inventec_event_data3_discrete_oem (ipmi_sel_parse_ctx_t ct
    * Inventec 5442/Dell Xanadu III
    */
 
-  if (ctx->manufacturer_id == IPMI_IANA_ENTERPRISE_ID_INVENTEC
-      && ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5442)
+  if (ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5442)
     {
       if (system_event_record_data->generator_id == IPMI_GENERATOR_ID_OEM_INVENTEC_SMI
           && system_event_record_data->event_type_code == IPMI_EVENT_READING_TYPE_CODE_SENSOR_SPECIFIC
@@ -517,9 +569,8 @@ ipmi_sel_parse_output_inventec_event_data3_discrete_oem (ipmi_sel_parse_ctx_t ct
    * Inventec 5442/Dell Xanadu III
    */
 
-  if (ctx->manufacturer_id == IPMI_IANA_ENTERPRISE_ID_INVENTEC
-      && (ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5441
-          || ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5442))
+  if ((ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5441
+       || ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5442))
     {
       if (system_event_record_data->generator_id == IPMI_SLAVE_ADDRESS_BMC
           && system_event_record_data->event_type_code == IPMI_EVENT_READING_TYPE_CODE_SENSOR_SPECIFIC
@@ -571,6 +622,7 @@ ipmi_sel_parse_output_inventec_event_data3_class_oem (ipmi_sel_parse_ctx_t ctx,
 {
   assert (ctx);
   assert (ctx->magic == IPMI_SEL_PARSE_CTX_MAGIC);
+  assert (ctx->manufacturer_id == IPMI_IANA_ENTERPRISE_ID_INVENTEC);
   assert (sel_parse_entry);
   assert (tmpbuf);
   assert (tmpbuflen);
@@ -584,23 +636,39 @@ ipmi_sel_parse_output_inventec_event_data3_class_oem (ipmi_sel_parse_ctx_t ctx,
    * Inventec 5441/Dell Xanadu II
    * Inventec 5442/Dell Xanadu III
    */
-  if (ctx->manufacturer_id == IPMI_IANA_ENTERPRISE_ID_INVENTEC
-      && (ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5441
-          || ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5442)
-      && system_event_record_data->generator_id == IPMI_GENERATOR_ID_OEM_INVENTEC_BIOS
-      && system_event_record_data->event_type_code == IPMI_EVENT_READING_TYPE_CODE_OEM_INVENTEC_BIOS
-      && system_event_record_data->sensor_type == IPMI_SENSOR_TYPE_OEM_INVENTEC_BIOS
-      && system_event_record_data->sensor_number == IPMI_SENSOR_NUMBER_OEM_INVENTEC_POST_START
-      && !system_event_record_data->offset_from_event_reading_type_code /* no event */
-      && system_event_record_data->event_data2_flag == IPMI_SEL_EVENT_DATA_OEM_CODE
-      && system_event_record_data->event_data3_flag == IPMI_SEL_EVENT_DATA_OEM_CODE)
+  if (ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5441
+      || ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5442)
     {
-      snprintf (tmpbuf,
-                tmpbuflen,
-                "BIOS Minor Version %02X",
-                system_event_record_data->event_data3);
+      int nmret;
+
+      if (system_event_record_data->generator_id == IPMI_GENERATOR_ID_OEM_INVENTEC_BIOS
+          && system_event_record_data->event_type_code == IPMI_EVENT_READING_TYPE_CODE_OEM_INVENTEC_BIOS
+          && system_event_record_data->sensor_type == IPMI_SENSOR_TYPE_OEM_INVENTEC_BIOS
+          && system_event_record_data->sensor_number == IPMI_SENSOR_NUMBER_OEM_INVENTEC_POST_START
+          && !system_event_record_data->offset_from_event_reading_type_code /* no event */
+          && system_event_record_data->event_data2_flag == IPMI_SEL_EVENT_DATA_OEM_CODE
+          && system_event_record_data->event_data3_flag == IPMI_SEL_EVENT_DATA_OEM_CODE)
+        {
+          snprintf (tmpbuf,
+                    tmpbuflen,
+                    "BIOS Minor Version %02X",
+                    system_event_record_data->event_data3);
       
-      return (1);
+          return (1);
+        }
+
+      if ((nmret = ipmi_sel_parse_output_intel_node_manager_event_data3_class_oem (ctx,
+                                                                                   sel_parse_entry,
+                                                                                   sel_record_type,
+                                                                                   tmpbuf,
+                                                                                   tmpbuflen,
+                                                                                   flags,
+                                                                                   wlen,
+                                                                                   system_event_record_data)) < 0)
+        return (-1);
+
+      if (nmret)
+        return (1);
     }
   
   return (0);
@@ -627,6 +695,7 @@ ipmi_sel_parse_output_inventec_event_data2_event_data3 (ipmi_sel_parse_ctx_t ctx
 {
   assert (ctx);
   assert (ctx->magic == IPMI_SEL_PARSE_CTX_MAGIC);
+  assert (ctx->manufacturer_id == IPMI_IANA_ENTERPRISE_ID_INVENTEC);
   assert (sel_parse_entry);
   assert (buf);
   assert (buflen);
@@ -641,14 +710,15 @@ ipmi_sel_parse_output_inventec_event_data2_event_data3 (ipmi_sel_parse_ctx_t ctx
    * Inventec 5441/Dell Xanadu II
    * Inventec 5442/Dell Xanadu III
    */
-  if (ctx->manufacturer_id == IPMI_IANA_ENTERPRISE_ID_INVENTEC
-      && (ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5441
-          || ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5442))
+  if ((ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5441
+       || ctx->product_id == IPMI_INVENTEC_PRODUCT_ID_5442))
     {
       if (system_event_record_data->generator_id == IPMI_GENERATOR_ID_OEM_INVENTEC_POST_ERROR_CODE
           && system_event_record_data->event_type_code == IPMI_EVENT_READING_TYPE_CODE_SENSOR_SPECIFIC
           && system_event_record_data->sensor_type == IPMI_SENSOR_TYPE_SYSTEM_FIRMWARE_PROGRESS
-          && system_event_record_data->sensor_number == IPMI_SENSOR_NUMBER_OEM_INVENTEC_POST_ERROR_CODE)
+          && system_event_record_data->sensor_number == IPMI_SENSOR_NUMBER_OEM_INVENTEC_POST_ERROR_CODE
+	  && system_event_record_data->event_data2_flag == IPMI_SEL_EVENT_DATA_OEM_CODE
+	  && system_event_record_data->event_data3_flag == IPMI_SEL_EVENT_DATA_OEM_CODE)
         {
           uint16_t error_code;
           char *error_code_str = NULL;
