@@ -1881,6 +1881,43 @@ ipmi_get_oem_sensor_type_message (uint32_t manufacturer_id,
   return (-1);
 }
 
+int
+ipmi_get_oem_specific_message (uint32_t manufacturer_id,
+                               uint16_t product_id,
+                               uint8_t event_reading_type_code,
+                               uint8_t sensor_type,
+                               unsigned int offset,
+                               char *buf,
+                               unsigned int buflen)
+{
+  if (!buf || !buflen)
+    {
+      SET_ERRNO (EINVAL);
+      return (-1);
+    }
+  
+  /* OEM Interpretation
+   *
+   * Intel S5500WB/Penguin Computing Relion 700
+   *
+   */
+  if (manufacturer_id == IPMI_IANA_ENTERPRISE_ID_INTEL
+      && product_id == IPMI_INTEL_PRODUCT_ID_S5500WB)
+    {
+      if ((event_reading_type_code == IPMI_EVENT_READING_TYPE_CODE_OEM_INTEL_PCIE_FATAL_SENSOR
+           || event_reading_type_code == IPMI_EVENT_READING_TYPE_CODE_OEM_INTEL_PCIE_CORRECTABLE_SENSOR)
+          && sensor_type == IPMI_SENSOR_TYPE_CRITICAL_INTERRUPT)
+        return (_get_event_message (offset,
+                                    buf,
+                                    buflen,
+                                    ipmi_oem_intel_specific_pci_fatal_sensor_max_index,
+                                    ipmi_oem_intel_specific_pci_fatal_sensor));
+    }
+  
+  SET_ERRNO (EINVAL);
+  return (-1);
+}
+
 int
 ipmi_get_oem_sensor_event_bitmask_message (uint32_t manufacturer_id,
 					   uint16_t product_id,
@@ -1949,3 +1986,4 @@ ipmi_get_oem_sensor_event_bitmask_message (uint32_t manufacturer_id,
   SET_ERRNO (EINVAL);
   return (-1);
 }
+
